package dev.fitko.fitconnect.client.sender.steps.unencrypted;

import dev.fitko.fitconnect.api.domain.model.metadata.AuthenticationInformation;
import dev.fitko.fitconnect.api.domain.model.metadata.payment.PaymentInformation;
import dev.fitko.fitconnect.api.domain.model.replychannel.ReplyChannel;
import dev.fitko.fitconnect.client.sender.model.Attachment;
import dev.fitko.fitconnect.client.sender.model.SendableSubmission;

import java.util.List;

public interface OptionalPropertiesStep {

    /**
     * Sends the submission with a list of attachments
     *
     * @param attachments that are sent with the submission
     * @return the next step where additional data can be added to the submission
     */
    OptionalPropertiesStep addAttachments(List<Attachment> attachments);

    /**
     * Sends the submission with an attachments
     *
     * @param attachment that is sent with the submission
     * @return the next step where additional data can be added to the submission
     */
    OptionalPropertiesStep addAttachment(Attachment attachment);

    /**
     * Add a reply channel. The {@link ReplyChannel} object provides static factories for all available options:
     * <ul>
     * <li>ReplyChannel.fromEmail(...)</li>
     * <li>ReplyChannel.fromDeMail(...)</li>
     * <li>ReplyChannel.fromFink(...)</li>
     * <li>ReplyChannel.fromElster(...)</li>
     *</ul>
     * @see <a href="https://docs.fitko.de/fit-connect/docs/metadata/replyChannel#r%C3%BCckkanal-replychannel">FIT-Connect documentation on reply channels</a>
     * @param replyChannel a configured reply channel
     * @return next step to set more additional properties
     */
    OptionalPropertiesStep setReplyChannel(ReplyChannel replyChannel);

    OptionalPropertiesStep setAuthenticationInformation(List<AuthenticationInformation> authenticationInformation);

    OptionalPropertiesStep setPaymentInformation(PaymentInformation paymentInformation);

    SendableSubmission build();
}
